const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const { version } = require('./package.json');
var webpack = require("webpack");

module.exports = {
  // entry: ['babel-polyfill', './index.js'],
  entry: './umd.js',
  output: {
    path: path.join(__dirname, '/lib'),
    filename: 'index.js',
    library: 'WebChat',
    libraryTarget: 'umd'
  },
  devServer: {
    stats: 'errors-only',
    host: process.env.HOST, // Defaults to `localhost`
    port: process.env.PORT, // Defaults to 8080
    open: true, // Open the page in browser
    contentBase: path.resolve(__dirname, '/lib')
  },
  resolve: {
    extensions: ['.js', '.jsx']
  },
  mode: 'development',
  devtool: 'eval-source-map',
  module: {
    rules: [{
      test: /\.(js|jsx)$/,
      exclude: /node_modules/,
      use: [
        {
          loader: 'string-replace-loader',
          options: {
            search: 'PACKAGE_VERSION_TO_BE_REPLACED',
            replace: version
          }
        },
        { loader: 'babel-loader' }
      ]
    }, {
      test: /\.scss$/,
      use: [
        { loader: 'style-loader' },
        { loader: 'css-loader' },
        {
          loader: 'sass-loader',
          options: {
            includePaths: [path.resolve(__dirname, 'src/scss/')]
          }
        }
      ]
    }, {
      test: /\.css$/,
      use: ['style-loader', 'css-loader']
    }, {
      test: /\.(jpg|png|gif|svg|woff|ttf|eot)$/,
      use: {
        loader: 'url-loader'
      }
    }]
  },
  plugins: [
    new HtmlWebpackPlugin({
      title: 'Web Chat Widget Test',
      filename: 'index.html',
      inject: false,
      template: 'dev/src/index.html',
      showErrors: true
    }),
    new webpack.BannerPlugin("Copyright 2022 Sages, Licensed under the Apache License, Version 2.0 (the \"License\") \n" +
    "you may not use this file except in compliance with the License.\n"  +
    "You may obtain a copy of the License at\n"  +
      "\n" +
       " http://www.apache.org/licenses/LICENSE-2.0\n"  +
      "\n" +
    "Unless required by applicable law or agreed to in writing, software\n"  +
    "distributed under the License is distributed on an \"AS IS\" BASIS,\n"  +
    "WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n"  +
    "See the License for the specific language governing permissions and\n" +
    "limitations under the License.")
  ]
};
